@@ -1,4 +1,4 @@
 from vtarget.dataprep import run_flow  # pyright: ignore
-from vtarget.utils.modeling import Modeling  # pyright: ignore
+from vtarget.utils.modeling import AutoMLSearch  # pyright: ignore
 
 hot_storage = dict()
