@@ -12,6 +12,7 @@ class Builder:
         self.cur_node_key: str = None
         self.dumpings = 0
         self.execution = 0
+        self.runnable = False
         # self.ultra = None
 
     def init_pipeline(self):
@@ -28,10 +29,12 @@ class Builder:
         script_handler.script.append("import pandas as pd")
         script_handler.script.append("import numpy as np")
 
-    def set_nodes(self, data: dict):
+    def set_nodes(self, flow_id: str, data: dict):
+        from vtarget.handlers.bug_handler import bug_handler
+
         self.nodes = {}  # Diccionario con los nodos del flujo cuya clave es el atributo "key" del nodo
         for idx, nd in enumerate(data["nodeDataArray"]):
-            if not ("isGroup" in nd and nd["isGroup"]) and (nd["type"] not in ["Comment"]):# and (nd["categoryId"] not in ["chart"]):  # no es grupo  # no es comment  # no es chart
+            if not ("isGroup" in nd and nd["isGroup"]) and (nd["type"] not in ["Comment"]):  # and (nd["categoryId"] not in ["chart"]):  # no es grupo  # no es comment  # no es chart
                 self.nodes[nd["key"]] = {
                     "idx": idx,
                     "key": nd["key"],
@@ -42,28 +45,45 @@ class Builder:
                     "loaded": False,
                     "childs": [],
                     "parents": [],
+                    "disabled": True if "meta" in nd and "disabled" in nd["meta"] and nd["meta"]["disabled"] else False,
                 }
 
-        # recorrer los links para obtener los padres e hijos por nodo
+        # * Recorre los links para obtener los padres e hijos por nodo
         for ld in data["linkDataArray"]:
             # if "_chart" in ld["to"]:
             #     continue
-            # Agrego los padres
-            parent = { "from": ld["from"], "frompid": ld["frompid"], "topid": ld["topid"] }
+
+            # ! Valida que el nodo existe
+            if ld["to"] not in self.nodes:
+                # TODO: Agregar al diccionario
+                msg = f'link {ld["key"]} to {ld["to"]}: hace referencia a nodo inexistente ({ld["to"]})'
+                bug_handler.default_node_log(flow_id, None, msg, console_level="trace", bug_level="warning", success=True)
+                continue
+
+            # ! Valida que el nodo existe
+            if ld["from"] not in self.nodes:
+                # TODO: Agregar al diccionario
+                msg = f'link {ld["key"]} from {ld["from"]}: hace referencia a nodo inexistente ({ld["from"]})'
+                bug_handler.default_node_log(flow_id, None, msg, console_level="trace", bug_level="warning", success=True)
+                continue
+
+            # * Agrega los padres
+            parent = {"from": ld["from"], "frompid": ld["frompid"], "topid": ld["topid"]}
             if not self.nodes[ld["to"]]["parents"]:
                 self.nodes[ld["to"]]["parents"] = [parent]
             else:
                 self.nodes[ld["to"]]["parents"].append(parent)
 
-            # Agrego los hijos
-            child = { "to": ld["to"], "topid": ld["topid"], "frompid": ld["frompid"], "to_id": self.nodes[ld["to"]]["idx"] }
+            # * Agrega los hijos
+            child = {"to": ld["to"], "topid": ld["topid"], "frompid": ld["frompid"], "to_idx": self.nodes[ld["to"]]["idx"]}
             if not self.nodes[ld["from"]]["childs"]:
                 self.nodes[ld["from"]]["childs"] = [child]
             else:
                 self.nodes[ld["from"]]["childs"].append(child)
 
-    # Resetea todos los nodos hijos cuando cambia la configuración de un padre
     def reset_childs_recursive(self, flow_id: str, node_key: str, reseted_nodes: list):
+        """Resetea todos los nodos hijos cuando cambia la configuración de un padre"""
+        
         import gc
 
         from vtarget.handlers.cache_handler import cache_handler
@@ -77,25 +97,27 @@ class Builder:
         gc.collect()
         return reseted_nodes
 
-    # Setea a True el parámetro para saltar (no-procesar) los nodos hijos cuando existe un error
     def set_skip_childs_recursive(self, flow_id: str, node_key: str, data: dict):
+        """Setea a True el parámetro para saltar (no-procesar) los nodos hijos cuando existe un error"""
+        
         for child in self.nodes[node_key]["childs"]:
             # Habilita la bandera para saltarse el nodo
             self.nodes[child["to"]]["skip"] = True
             # Resetea el df completo almacenado en RAM
             self.nodes[child["to"]]["output"] = None
             # Resetea el nodo de gojs
-            for port_name in data["nodeDataArray"][child["to_id"]]["meta"]["ports_map"]["pout"]:
-                data["nodeDataArray"][child["to_id"]]["meta"]["ports_map"]["pout"][port_name]["head"] = []
-                data["nodeDataArray"][child["to_id"]]["meta"]["ports_map"]["pout"][port_name]["rows"] = 0
-                data["nodeDataArray"][child["to_id"]]["meta"]["ports_map"]["pout"][port_name]["cols"] = 0
-            data["nodeDataArray"][child["to_id"]]["meta"]["skipped"] = True
+            for port_name in data["nodeDataArray"][child["to_idx"]]["meta"]["ports_map"]["pout"]:
+                data["nodeDataArray"][child["to_idx"]]["meta"]["ports_map"]["pout"][port_name]["head"] = []
+                data["nodeDataArray"][child["to_idx"]]["meta"]["ports_map"]["pout"][port_name]["rows"] = 0
+                data["nodeDataArray"][child["to_idx"]]["meta"]["ports_map"]["pout"][port_name]["cols"] = 0
+            data["nodeDataArray"][child["to_idx"]]["meta"]["skipped"] = True
             print("=================> se saltará el nodo", child["to"])
             self.set_skip_childs_recursive(flow_id, child["to"], data)
         return True
 
-    # Checkea si todos los hijos están listos
     def check_childs_loaded(self, node_key: str):
+        """Checkea si todos los hijos están listos"""
+        
         loaded = True
         for child in self.nodes[node_key]["childs"]:
             if not self.nodes[child["to"]]["loaded"]:
@@ -103,8 +125,9 @@ class Builder:
                 break
         return loaded
 
-    # Manda a almacenar y liberar los padres que ya están listos
     def dump_parents(self, flow_id, node_key):
+        """Manda a almacenar y liberar los padres que ya están listos"""
+        
         import time
 
         from vtarget.handlers.cache_handler import cache_handler
@@ -113,7 +136,6 @@ class Builder:
             return
 
         t = time.time()
-
         if not self.nodes[node_key]["loaded"]:
             return
         for parent in self.nodes[node_key]["parents"]:
@@ -123,6 +145,9 @@ class Builder:
             cache_handler.dump(flow_id, node_key)
         self.dumpings += time.time() - t
 
+    def stop_model(self):
+        self.runnable = False
+
     def analyzer(
         self,
         data: dict,
@@ -146,139 +171,171 @@ class Builder:
         from vtarget.handlers.event_handler import event_handler
         from vtarget.handlers.log_handler import log_handler
         from vtarget.handlers.script_handler import script_handler
+        import math
 
         print("deploy_enabled", deploy_enabled)
-
+        
+        self.runnable = True
         self.dumpings = 0
         self.execution = 0
 
-        # Reseteo de variables singleton para cada ejecución
+        # * Reseteo de variables singleton para cada ejecución
         log_handler.log = []
         bug_handler.bug = []
         script_handler.script = []
 
-        # Si se corre el flujo reseteando la cache
+        # * Si se corre el flujo reseteando la cache
         if reset_cache:
             msg = app_message.dataprep["builder"]["reset_cache"](flow_name)
-            bug_handler.default_on_error(flow_id, None, msg, console_level="trace", bug_level="info", success=True)
+            bug_handler.default_node_log(flow_id, None, msg, console_level="trace", bug_level="info", success=True)
             cache_handler.reset(flow_id)
 
-        # Incializa la caché para el nodo si es que aún no existe
+        # * Inicializa la caché para el flujo si es que aún no existe
         cache_handler.load_settings(flow_id)
         if flow_id not in cache_handler.cache:
             cache_handler.cache[flow_id] = dict()
 
         cache_nodes_keys = list(cache_handler.cache[flow_id].keys())
-
         msg = app_message.dataprep["builder"]["nodes_in_cache"](str(len(cache_nodes_keys)))
-        bug_handler.default_on_error(flow_id, None, msg, console_level="trace", bug_level="info", success=True)
+        bug_handler.default_node_log(flow_id, None, msg, console_level="trace", bug_level="info", success=True)
 
-        # Inicializa una copia local de los nodos y su metadata
-        self.set_nodes(data)
+        # * Hace una copia local de los nodos y su metadata
+        self.set_nodes(flow_id, data)
 
+        completed_nodes: list = []
         num_nodes_ok: int = 0  # conteo del número de nodos procesados
         attemps: int = 0  # contador de intentos del while para procesar el flujo completo
         t1 = time.time()  # inicializa el tiempo total de procesamiento de los nodos
-        completed_nodes: list = []
 
-        # mientras no estén todos los nodos procesados
-        while num_nodes_ok < len(self.nodes):
+        # * Itera mientras no estén todos los nodos procesados (prop loaded == True)
+        while self.runnable and num_nodes_ok < len(self.nodes):
             # print(num_nodes_ok, "<", len(self.nodes))
             attemps += 1
             for node_key, node_data in self.nodes.items():
-                # Salto los nodos que están cargado
+                node_idx: int = self.nodes[node_key]["idx"]
+                
+                if not self.runnable:
+                    msg = app_message.dataprep["builder"]["stopped_flow"]
+                    bug_handler.default_node_log(flow_id, None, msg, console_level="error", bug_level="warning", success=True)
+                    break
+                
+                # * Salta los nodos que ya han sido procesados
                 if self.nodes[node_key]["loaded"]:
                     continue
 
-                # * Salto los nodos output data cuando el check de deshabilitar está activado
-                if (disable_all_write_nodes and (node_data["type"] in [NodeType.OUTPUTDATA.value, NodeType.EXCEL.value, NodeType.DATABASEWRITE.value])) or (
-                    disable_all_email_nodes and (node_data["type"] in [NodeType.EMAIL.value])
-                ):
+                # * Salta los nodos output y email cuando el check de deshabilitar está activado
+                if (
+                    (disable_all_write_nodes and (node_data["type"] in [NodeType.OUTPUTDATA.value, NodeType.EXCEL.value, NodeType.DATABASEWRITE.value])) 
+                    or
+                    (disable_all_email_nodes and (node_data["type"] in [NodeType.EMAIL.value]))
+                    ):
+                    
                     if node_data["type"] in [NodeType.EMAIL.value]:
-                        msg = app_message.dataprep["builder"]["not_send"](node_data["key"])
+                        msg = app_message.dataprep["builder"]["not_send"](node_key)
                     else:
-                        msg = app_message.dataprep["builder"]["skip_writing"](node_data["key"])
-                    bug_handler.default_on_error(flow_id, None, msg, console_level="trace", bug_level="info", success=True)
+                        msg = app_message.dataprep["builder"]["skip_writing"](node_key)
+                    bug_handler.default_node_log(flow_id, None, msg, console_level="trace", bug_level="info", success=True)
 
-                    # Para que no entre dos veces en caso que el while haga mas de un intento
+                    # * Se establece como loaded = True para que no entre nuevamente en caso que el while haga mas de un intento
                     self.nodes[node_key]["loaded"] = True
-                    node_idx: int = self.nodes[node_key]["idx"]
                     data["nodeDataArray"][node_idx]["meta"]["skipped"] = False
                     self.dump_parents(flow_id, node_key)
-                    if node_data["key"] not in completed_nodes:
+                    # * Agrega nodo a lista de completados
+                    if node_key not in completed_nodes:
                         num_nodes_ok += 1
-                        completed_nodes.append(node_data["key"])
+                        completed_nodes.append(node_key)
                     continue
 
-                # Omito procesar los nodos hijos de un nodo que tuvo un error
+                # * Omitir el procesamiento de nodos saltados por un error en el nodo padre
                 if self.nodes[node_key]["skip"]:
                     # TODO: Pancho aquí te falto traducción
+                    # * Se establece como loaded = True para que no entre nuevamente en caso que el while haga mas de un intento
                     self.nodes[node_key]["loaded"] = True
-                    bug_handler.console("nodo {} saltado".format(node_data["key"]), "trace", flow_id)
-                    if node_data["key"] not in completed_nodes:
+                    bug_handler.console("Nodo {} saltado".format(node_key), "trace", flow_id)
+                    # * Agrega nodo a lista de completados
+                    if node_key not in completed_nodes:
                         num_nodes_ok += 1
-                        completed_nodes.append(node_data["key"])
+                        completed_nodes.append(node_key)
+                    continue
+                
+                # * Omitir el procesamiento de nodos deshabilitados desde la vista
+                if self.nodes[node_key]["disabled"]:
+                    # TODO: Pancho aquí te falto traducción
+                    # * Se establece como loaded = True para que no entre nuevamente en caso que el while haga mas de un intento
+                    self.nodes[node_key]["loaded"] = True
+                    bug_handler.console("Nodo {} dehabilitado".format(node_key), "trace", flow_id)
+                    # * Agrega nodo a lista de completados
+                    if node_key not in completed_nodes:
+                        num_nodes_ok += 1
+                        completed_nodes.append(node_key)
                     continue
 
-                # --------------------------------------------------
-                # Dertermina si el/los nodos padres están cargados
-                # --------------------------------------------------
-                is_loaded = False
+                # * --------------------------------------------------
+                # * Determina si el nodo puede ser procesado
+                # * --------------------------------------------------
+                ready_to_exec = False # * Solo es verdadero cuando todos los nodos padres han sido procesados
                 to_load_input_port: Dict[str, Dict[str, Any]] = {}
-                # Almancena los df del mapeo de los puertos de entrada
+                # * Almacena los df del mapeo de los puertos de entrada
                 input_port: Dict[str, pd.DataFrame] = {}
-                # Si es una entrada de datos que no tiene padre, se puede procesar
+                
+                # * Si el nodo no posee padres, se puede procesar
                 if not node_data["parents"]:
-                    # Omite los nodos de entrada de datos (sin puertos de entrada), ya que por consecuencia no tiene registro de nodos padres
+                    # * Nodos de entrada pueden procesarse inmediatamente ya que no tienen registro de nodos padres
                     if node_data["type"] in [
                         NodeType.INPUTDATA.value,
                         NodeType.DFMAKER.value,
                         NodeType.DATABASE.value,
                         NodeType.SOURCE.value,
                         NodeType.DATETIMERANGE.value,
+                        NodeType.APIREST.value,
                     ]:
-                        is_loaded = True
+                        ready_to_exec = True
                     else:
-                        msg = app_message.dataprep["builder"]["parent_without_entry"](node_data["key"])
-                        bug_handler.default_on_error( flow_id, None, msg, console_level="trace", bug_level="info", success=True)
+                        # * Error si el nodo no tiene registro de padres, pero debería tenerlos
+                        msg = app_message.dataprep["builder"]["parent_without_entry"](node_key)
+                        bug_handler.default_node_log(flow_id, None, msg, console_level="trace", bug_level="info", success=True)
 
-                        # Para que no entre dos veces en caso que el while haga mas de un intento
+                        # * Se establece como loaded = True para que no entre nuevamente en caso que el while haga mas de un intento
                         self.nodes[node_key]["loaded"] = True
                         self.dump_parents(flow_id, node_key)
-                        if node_data["key"] not in completed_nodes:
+                        # * Agrega nodo a lista de completados
+                        if node_key not in completed_nodes:
                             num_nodes_ok += 1
-                            completed_nodes.append(node_data["key"])
+                            completed_nodes.append(node_key)
+                            
+                        # * Saltar rama del nodo
                         self.set_skip_childs_recursive(flow_id, node_key, data)
                         continue
-                else:  # Si el nodo tiene padres
-                    # Compruebo si todos los padres tienen sus salidas cargadas
+                    
+                else:  # * Si el nodo tiene padres
+                    # * Verificar que todos los padres tienen sus salidas cargadas (que han sido procesados)
                     for parent in node_data["parents"]:
-                        is_loaded = True  # incializo la carga en verdadero
-                        # Si está la salida en el nodo padre
+                        ready_to_exec = True  # inicializo la carga en verdadero
+                        # * Si el nodo padre posee salida
                         if self.nodes[parent["from"]]["output"] != None:
-                            # if parent['from'] in cache_handler.cache[flow_id]:
-                            to_load_input_port[parent["topid"]] = { "node_key": parent["from"], "port_name": parent["frompid"] }
-                            # Almaceno en el mapeo de entrada del nodo el df asociado a la salida del padre
-                        else:  # Si al menos un padre no está procesado, etonces termina la iteración
-                            is_loaded = False  # si al menos uno no está cargado
+                            # Almacena temporalmente la salida del padre para cargarla posteriomente como entrada del nodo hijo
+                            to_load_input_port[parent["topid"]] = {"node_key": parent["from"], "port_name": parent["frompid"]}
+                        else: 
+                            # *Si al menos un padre no está procesado, entonces termina la iteración
+                            ready_to_exec = False
                             break
 
-                # --------------------------------------------------
-                # Si el nodo se puede procesar inicia el procesamiento
-                # --------------------------------------------------
-                if is_loaded:
-                    node_idx: int = self.nodes[node_key]["idx"]
-                    node_key: str = data["nodeDataArray"][node_idx]["key"]
-                    node_name: str = data["nodeDataArray"][node_idx]["name"]
+                # * --------------------------------------------------
+                # * Si el nodo se puede procesar, inicia el procesamiento
+                # * --------------------------------------------------
+                if ready_to_exec:
+                    # node_key: str = data["nodeDataArray"][node_idx]["key"]
+                    # node_name: str = data["nodeDataArray"][node_idx]["name"]
+                    node_name: str = node_data["name"]
                     has_error: bool = False
                     self.cur_node_key = node_key
 
-                    # --------------------------------------------------
-                    # Valida si el nodo actual está en caché y si su configuración sigue siendo la misma
-                    # --------------------------------------------------
                     node_settings = cache_handler.settings[flow_id][node_key] if node_key in cache_handler.settings[flow_id] else dict()
                     node_in_cache = len(node_settings) > 0 and node_key in cache_handler.cache[flow_id]
-                    
+
+                    # * --------------------------------------------------
+                    # * Si el nodo actual está en caché y su config no ha cambiado, entonces no lo procesa
+                    # * --------------------------------------------------
                     if (
                         node_in_cache
                         and "config" in node_settings
@@ -298,52 +355,47 @@ class Builder:
                         data["nodeDataArray"][node_idx]["meta"]["readed_from_cache"] = True
                         data["nodeDataArray"][node_idx]["meta"]["processed"] = True
                         script_handler.script += node_settings["script"]
-                    # --------------------------------------------------
-                    # Procesa el nodo correspondiente y actualiza los valores de los df
-                    # --------------------------------------------------
+                    # * --------------------------------------------------
+                    # * De lo contrario, procesa y actualiza los valores de los df de salida
+                    # * --------------------------------------------------
                     else:
-                        # --------------------------------------------------
-                        # Actualizo los dtypes de la entrada con el dataframe de la salida del nodo anterior
-                        # --------------------------------------------------
-                        # Omite nodos de entrada de datos (sin puertos de entrada)
                         if node_data["type"] not in [
                             NodeType.INPUTDATA.value,
                             NodeType.DFMAKER.value,
                             NodeType.DATABASE.value,
                             NodeType.SOURCE.value,
                             NodeType.DATETIMERANGE.value,
+                            NodeType.APIREST.value,
                         ]:
+                            # * Recorre los puertos del entrada del nodo
                             for _, pin_name in enumerate(data["nodeDataArray"][node_idx]["meta"]["ports_map"]["pin"]):
                                 if "dtypes" in data["nodeDataArray"][node_idx]["meta"]["ports_map"]["pin"][pin_name] and pin_name in to_load_input_port:
+                                    # * Carga salida del padre desde caché
                                     to_load = to_load_input_port[pin_name]
-
                                     cache_handler.load(flow_id, to_load["node_key"], to_load["port_name"])
-
                                     parent_key = to_load["node_key"]
                                     parent_port = to_load["port_name"]
                                     parent_cache = (
                                         cache_handler.cache[flow_id][parent_key] if flow_id in cache_handler.cache and parent_key in cache_handler.cache[flow_id] else dict()
                                     )
-
+                                    
+                                    # * Actualiza los dtypes de la entrada del nodo con el dataframe de la salida del nodo anterior
                                     if parent_cache and "pout" in parent_cache and parent_port in parent_cache["pout"]:
                                         input_port[pin_name] = parent_cache["pout"][parent_port]
-
                                         dtypes_list = data["nodeDataArray"][node_idx]["meta"]["ports_map"]["pin"][pin_name]["dtypes"]
-
+                                        
                                         # NOTE: ¿Esto se ejecuta siempre o solo la primera vez que se carga el nodo?
                                         u_dtypes = self.update_inputs_dtypes(node_name, node_key, dtypes_list, input_port[pin_name])
-
                                         data["nodeDataArray"][node_idx]["meta"]["ports_map"]["pin"][pin_name]["dtypes"] = u_dtypes
                                         # print(pin_index, 'fin')
 
-                        # --------------------------------------------------
-                        # Continua con el procesamiento de los nodos que han cambiado
-                        # --------------------------------------------------
+                        # * --------------------------------------------------
+                        # * Verifica si el nodo existía en caché, pero su config se modificó
+                        # * --------------------------------------------------
                         bug_handler.console(f"PROCESANDO NODO {node_key}", "-", flow_id)
                         if node_settings and (
                             (
-                                "config" in node_settings
-                                and node_settings["config"] != json.dumps( data["nodeDataArray"][node_idx]["meta"]["config"], sort_keys=True)
+                                "config" in node_settings and node_settings["config"] != json.dumps(data["nodeDataArray"][node_idx]["meta"]["config"], sort_keys=True)
                             )  # node config ha cambiado
                             or (
                                 "ports_config" in node_settings  # existe ports_config en cache
@@ -351,6 +403,7 @@ class Builder:
                                 and node_settings["ports_config"] != json.dumps(data["nodeDataArray"][node_idx]["meta"]["ports_config"], sort_keys=True)
                             )  # node ports_config ha cambiado
                         ):
+                            # * Resetea la rama completa del nodo y envia lista de nodos a la vista
                             reseted_nodes = self.reset_childs_recursive(flow_id, node_key, [node_key])
                             event_handler.emit_queue.put(
                                 {
@@ -364,16 +417,22 @@ class Builder:
 
                         t = time.time()
 
-                        # agrega parametro de despliegue a la config de cada nodo
+                        # ! Agrega parametro de despliegue a la config de cada nodo
                         if "meta" in data["nodeDataArray"][node_idx] and "config" in data["nodeDataArray"][node_idx]["meta"]:
                             data["nodeDataArray"][node_idx]["meta"]["config"]["deploy_enabled"] = deploy_enabled
-                        
-                        # procesa todos los nodos excepto los de tipo chart
+
+                        # * Procesa todos los nodos excepto los de tipo chart
                         if "categoryId" in data["nodeDataArray"][node_idx] and data["nodeDataArray"][node_idx]["categoryId"] != "chart":
+                            # ! restea paginacion a 1
+                            if "ports_config" in data["nodeDataArray"][node_idx]["meta"] and data["nodeDataArray"][node_idx]["meta"]["ports_config"] is not None:
+                                for port in data["nodeDataArray"][node_idx]["meta"]["ports_config"]:
+                                    data["nodeDataArray"][node_idx]["meta"]["ports_config"][port]["page"] = 1
+                                    
+                            # * Ejecucion individual de cada nodo
                             data["nodeDataArray"][node_idx] = self.pipeline.exec(flow_id, data["nodeDataArray"][node_idx], input_port)
                         else:
                             print(f'{data["nodeDataArray"][node_idx]["type"]} no se procesa')
-                            
+
                         self.execution += time.time() - t
                         # print(self.execution)
 
@@ -384,10 +443,11 @@ class Builder:
                             )
                             != None
                         )
-                        
+
                         data["nodeDataArray"][node_idx]["meta"]["processed"] = True
                         data["nodeDataArray"][node_idx]["meta"]["has_error"] = has_error
 
+                        # * Envía nodos procesado a la vista
                         event_handler.emit_queue.put(
                             {
                                 "name": "dataprep.node_processed",
@@ -395,41 +455,40 @@ class Builder:
                                     "flow_id": flow_id,
                                     "key": node_key,
                                     "node": json.dumps(data["nodeDataArray"][node_idx], default=str),
+                                    "progress": math.floor(((num_nodes_ok+1) / len(self.nodes)) * 100) if len(self.nodes) > 0 else 0
                                     # 'log': log_handler.log, # TODO: Hacer el log del nodo correspondiente
                                 },
                             }
                         )
 
-                    # Almaceno los df del mapeo de salida
+                    # * Establece que el nodo se ha procesado y se ha generado una salida
                     self.nodes[node_key]["output"] = True
-                    # Fijo la bandera mara para marcar que el nodo está procesado
+                    # * Se establece como loaded = True para que no entre nuevamente en caso que el while haga mas de un intento
                     self.nodes[node_key]["loaded"] = True
                     self.dump_parents(flow_id, node_key)
-                    # Aumento el contador para saber que ese nodo fue analizado y salir del while
-                    if node_data["key"] not in completed_nodes:
+                    # * Agrega nodo a lista de completados
+                    if node_key not in completed_nodes:
                         num_nodes_ok += 1
-                        completed_nodes.append(node_data["key"])
+                        completed_nodes.append(node_key)
 
-                    # --------------------------------------------------
-                    # Valida si el nodo actual se registró en el singleton de bug con level==error, de estarlo se saltan los hijos de esos nodos
-                    # --------------------------------------------------
+                    # * Verifica si el nodo fue procesado con error
                     data["nodeDataArray"][node_idx]["meta"]["skipped"] = False
-                    data["nodeDataArray"][node_idx]["meta"]["has_error"] = False
                     if has_error:
                         print("\n\n\n----------- has_error", has_error)
                         cache_handler.delete_node(flow_id, node_key)
-                        data["nodeDataArray"][node_idx]["meta"]["has_error"] = True
-                        self.set_skip_childs_recursive(flow_id, node_key, data)
+                        data["nodeDataArray"][node_idx]["meta"]["has_error"] = True # * Marca nodo como error
+                        self.set_skip_childs_recursive(flow_id, node_key, data) # * Saltar rama del nodo
 
-        # --------------------------------------------------
-        # Fin del while y for principal
-        # --------------------------------------------------
+        # * --------------------------------------------------
+        # * Fin del while y for principal
+        # * --------------------------------------------------
+        
         cache_nodes_keys = list(cache_handler.settings[flow_id].keys())
         msg = app_message.dataprep["builder"]["save_cache"](len(cache_nodes_keys))
-        bug_handler.default_on_error(flow_id, None, msg, console_level="debug", bug_level="info", success=True)
+        bug_handler.default_node_log(flow_id, None, msg, console_level="debug", bug_level="info", success=True)
 
         msg = app_message.dataprep["builder"]["processed_flow"](str(round(time.time() - t1, 3)))
-        bug_handler.default_on_error(flow_id, None, msg, console_level="debug", bug_level="info", success=True)
+        bug_handler.default_node_log(flow_id, None, msg, console_level="debug", bug_level="info", success=True)
 
         print(self.dumpings, "dumpings")
         print(self.execution, "execution")
@@ -596,11 +655,12 @@ class Builder:
         return {"flow_id": flow_id, "node_key": node_key, "node": node, "success": True}
 
     def run_node(self, flow_id: str, node_key: str, node: dict, links_to: list):
-        if 'CHART' in node_key.upper():
+        if "CHART" in node_key.upper():
             return
-        
+
         import json
         from typing import Dict
+
         import pandas as pd
 
         from vtarget.handlers.bug_handler import bug_handler
@@ -632,6 +692,11 @@ class Builder:
             if parent_cache and "pout" in parent_cache and parent_port in parent_cache["pout"]:
                 input_port[node_port] = parent_cache["pout"][parent_port]  # actualiza pin del nodo con la salida correspondiente del padre
 
+        # ! restea paginacion a 1
+        if "ports_config" in node["meta"] and node["meta"]["ports_config"] is not None:
+            for port in node["meta"]["ports_config"]:
+                node["meta"]["ports_config"][port]["page"] = 1
+
         node = self.pipeline.exec(flow_id, node, input_port)
 
         # Valida si la ejecucion del nodo tuvo algun error
@@ -653,6 +718,7 @@ class Builder:
                     "flow_id": flow_id,
                     "key": node_key,
                     "node": json.dumps(node, default=str),
+                    "progress": 100
                 },
             }
         )
