@@ -75,7 +75,7 @@ class Code:
 
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            default = bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            default = bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
             default["STDOUT"] = stdout
             default["STDOUT"] += str(e)
             return default
@@ -85,7 +85,7 @@ class Code:
             globals()["vtg_df"] = []
             if not isinstance(df_out, pd.DataFrame):
                 msg = app_message.dataprep["nodes"]["code"]["no_vtg_codeout"](node_key)
-                default = bug_handler.default_on_error(flow_id, node_key, msg, "", "error")
+                default = bug_handler.default_node_log(flow_id, node_key, msg, "", "error")
                 default["STDOUT"] = stdout
                 return default
 
