@@ -16,22 +16,22 @@ class Cumsum:
         script.append("\n# CUMSUM")
 
         groupby: list = settings["groupby"] if "groupby" in settings and settings["groupby"] else []
-        axis: str = settings["axis"] if "axis" in settings and settings["axis"] else None
         cumcount: bool = settings["cumcount"] if "cumcount" in settings else False
         cumsum: bool = settings["cumsum"] if "cumsum" in settings else False
         cumpct: bool = settings["cumpct"] if "cumpct" in settings else False
+        axis: str = settings["axis"] if "axis" in settings and settings["axis"] else None
         pct: bool = settings["pct"] if "pct" in settings else False
 
         if not axis:
             msg = app_message.dataprep["nodes"]["missing_column"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
         prefix = axis[:3]
         script.append(f"prefix = '{prefix}'")
 
         if not (cumcount or cumsum or cumpct or pct):
             msg = app_message.dataprep["nodes"]["cumsum"]["aggregation_required"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="warn", bug_level="warning", success=True)
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="warn", bug_level="warning", success=True)
 
         try:
             if groupby:
@@ -64,7 +64,7 @@ class Cumsum:
                     script.append(f"df[prefix+'_cumpct'] = df['{axis}'].cumsum()/df['{axis}'].sum()")
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
