@@ -12,42 +12,54 @@ from vtarget.utils.database_connection.utilities import database_utilities
 
 class DatabaseWrite:
     def exec(self, flow_id, node_key, pin, settings):
+        import re
+
         import pyodbc
         import snowflake.connector
         from google.oauth2 import service_account
         from pymongo import MongoClient
         from snowflake.connector.pandas_tools import write_pandas
         from sqlalchemy import create_engine
+        from sqlalchemy.exc import ProgrammingError
 
         df: pd.DataFrame = pin["In"].copy()
         script = []
         script.append("\n# DATABASE WRITE")
 
         try:
-            # Valida los campos de entrada y los nombres de los campos que utilizará cada conexión
+            # * Valida que existan todos los campos requeridos y que no estén vacíos dependiendo del tipo de conexion
             checked, msg = database_utilities.check_fields(settings, tier="write_data", node_key=node_key)
-
             if not checked:
-                return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
+
+            prefix: str = ""
+            deploy_enabled: bool = settings["deploy_enabled"] if "deploy_enabled" in settings else False
+
+            if deploy_enabled:
+                prefix = "deploy_"
+
+            source = settings[f"{prefix}source"]
 
-            source = settings["source"]
             if source == "postgresql" or source == "mysql" or source == "sqlite" or source == "mariadb" or source == "oracle":
-                table = settings["table"]
-                save_type = settings["save_type"]
-                connection = database_utilities.get_url_connection(settings, with_database=True)
+                table = settings[f"{prefix}table"]
+                save_type = settings[f"{prefix}save_type"]
+
+                connection = database_utilities.get_url_connection(flow_id, settings, with_database=True)
                 engine = create_engine(connection)
                 df.to_sql(name=table, con=engine, if_exists=save_type, index=False)
                 engine.dispose()
 
             elif source == "sqlserver_2000":
-                table = settings["table"]
-                save_type = settings["save_type"]
-                connection = database_utilities.get_url_connection(settings, True)
+                table = settings[f"{prefix}table"]
+                save_type = settings[f"{prefix}save_type"]
+
+                connection = database_utilities.get_url_connection(flow_id, settings, True)
                 try:
                     engine = pyodbc.connect(connection)
                 except Exception as e:
-                    settings["source"] = "sqlserver_2000_v2"
-                    connection = database_utilities.get_url_connection(settings, True)
+                    #TODO: Agregar a la lista de opciones de la vista
+                    settings[f"{prefix}source"] = "sqlserver_2000_v2"
+                    connection = database_utilities.get_url_connection(flow_id, settings, True)
                     engine = pyodbc.connect(connection)
                 cursor = engine.cursor()
                 # Preparación de datos
@@ -65,11 +77,12 @@ class DatabaseWrite:
                 engine.close()
 
             elif source == "bigquery":
-                service_account_host = settings["service_account_host"]
-                database = settings["database"]
-                project = settings["project"]
-                table = settings["table"]
-                save_type = settings["save_type"]
+                service_account_host = settings[f"{prefix}service_account_host"]
+                database = settings[f"{prefix}database"]
+                project = settings[f"{prefix}project"]
+                table = settings[f"{prefix}table"]
+                save_type = settings[f"{prefix}save_type"]
+
                 with open(service_account_host) as file:
                     service_account_host = json.load(file)
                     credentials = service_account.Credentials.from_service_account_info(service_account_host)
@@ -81,13 +94,14 @@ class DatabaseWrite:
                     )
 
             elif source == "snowflake":
-                table = settings["table"]
-                user = settings["user"]
-                database = settings["database"]
-                project = settings["project"]
-                account = settings["account"]
-                password = settings["password"]
-                save_type = settings["save_type"]
+                table = settings[f"{prefix}table"]
+                user = settings[f"{prefix}user"]
+                database = settings[f"{prefix}database"]
+                project = settings[f"{prefix}project"]
+                account = settings[f"{prefix}account"]
+                password = settings[f"{prefix}password"]
+                save_type = settings[f"{prefix}save_type"]
+
                 connection = snowflake.connector.connect(user=user, password=password, account=account, database=project, schema=database)
                 write_pandas(
                     connection,
@@ -101,10 +115,11 @@ class DatabaseWrite:
                 connection.close()
 
             elif source == "mongodb":
-                mongo_client = settings["mongo_client"]
-                database = settings["database"]
-                table = settings["table"]
-                save_type = settings["save_type"]
+                mongo_client = settings[f"{prefix}mongo_client"]
+                database = settings[f"{prefix}database"]
+                table = settings[f"{prefix}table"]
+                save_type = settings[f"{prefix}save_type"]
+
                 client = MongoClient(mongo_client)
                 db = client[database]
                 collection = db[table]
@@ -115,11 +130,26 @@ class DatabaseWrite:
 
             else:
                 msg = app_message.dataprep["nodes"]["database_write"]["source_required"](node_key)
-                return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
+        except ProgrammingError as e:
+            # Utiliza expresiones regulares para extraer el nombre de la columna y la tabla desde el mensaje de error
+            column_match = re.search(r'column "(.*?)" of relation', str(e.orig))
+            table_match = re.search(r'relation "(.*?)" does not exist', str(e.orig))
+
+            column_name = column_match.group(1) if column_match else None
+            table_name = table_match.group(1) if table_match else None
+            
+            if column_name and table_name:
+                msg = app_message.dataprep["nodes"]["database_write"]["no_column_in_table"](node_key, column_name, table_name)
+            else:
+                msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
+                
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
@@ -132,4 +162,4 @@ class DatabaseWrite:
         )
 
         script_handler.script += script
-        return {"Out": df}
+        return {"Out": df}
\ No newline at end of file
