@@ -24,20 +24,17 @@ class DatetimeExtract:
                 to_extract: str = item["to_extract"] if ("to_extract" in item and item["to_extract"]) else ""
                 new_column_name: str = item["new_column_name"] if "new_column_name" in item and item["new_column_name"] else to_extract.replace("()", "")
 
-                msg: str = None
                 if not to_extract or not column_to_convert:
                     msg = app_message.dataprep["nodes"]["missing_column"](node_key)
-
-                if msg:
-                    return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                    return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
                 try:
                     df[new_column_name] = eval("df[column_to_convert].dt.{}".format(to_extract))
-                    script.append(f'df["{new_column_name}"] = df[column_to_convert].dt.{to_extract}')
+                    script.append(f'df["{new_column_name}"] = df["{column_to_convert}"].dt.{to_extract}')
 
                 except Exception as e:
                     msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-                    return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+                    return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
             cache_handler.update_node(
                 flow_id,
@@ -52,4 +49,4 @@ class DatetimeExtract:
             return {"Out": df}
         else:
             msg = app_message.dataprep["nodes"]["missing_column"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
