@@ -27,34 +27,29 @@ class DatetimeFormatter:
 
                 if not column_to_convert:
                     msg = app_message.dataprep["nodes"]["missing_column"](node_key)
-                    return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                    return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
                 if custom_pattern:
                     if custom_pattern[0] not in ["'", '"'] or custom_pattern[-1] not in ["'", '"']:
                         msg = app_message.dataprep["nodes"]["datetime_formatter"]["pattern_quotes"](node_key)
-                        return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                        return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
                     preconfigured_pattern = custom_pattern[1:-1]
                 else:
                     if not preconfigured_pattern:
                         msg = app_message.dataprep["nodes"]["datetime_formatter"]["pattern_required"](node_key)
-                        return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                        return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
                 try:
-                    script.append(f"""df["{new_column_name}"] = df.apply(lambda x: process_datetime(x["{column_to_convert}"], "{preconfigured_pattern}"), axis=1)""")
-                    
                     if df[column_to_convert].dtype == "object":
                         df[new_column_name] = pd.to_datetime(df[column_to_convert], format=preconfigured_pattern)
+                        script.append(f"df['{new_column_name}'] = pd.to_datetime(df['{column_to_convert}'], format='{preconfigured_pattern}')")
                     else:
                         df[new_column_name] = df[column_to_convert].dt.strftime(preconfigured_pattern)
-
-                    # df[new_column_name] = df.apply(
-                    #     lambda x: self.process_datetime(x[column_to_convert], preconfigured_pattern, script),
-                    #     axis=1,
-                    # )
+                        script.append(f"df['{new_column_name}'] = df['{column_to_convert}'].dt.strftime('{preconfigured_pattern}')")
 
                 except Exception as e:
                     msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-                    return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+                    return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
             cache_handler.update_node(
                 flow_id,
@@ -69,7 +64,7 @@ class DatetimeFormatter:
             return {"Out": df}
         else:
             msg = app_message.dataprep["nodes"]["missing_column"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
     # def process_datetime(self, _datetime, pattern, script):
     #     # Hay que ver por qué ocurren estos 2 casos
