@@ -26,7 +26,7 @@ class Describe:
 
         if not fields:
             msg = app_message.dataprep["nodes"]["missing_column"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
         fields = list(filter(lambda x: x in df.columns, fields))
         all_percentiles = percentiles + custom_percentiles
@@ -59,7 +59,7 @@ class Describe:
 
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         df = df.round(2)
         cache_handler.update_node(
