@@ -15,8 +15,8 @@ class DropDuplicates:
         df: pd.DataFrame = pin["In"].copy()
         script.append("\n# Drop Duplicates")
 
-        columns: list[str] = settings["columns"] if ("columns" in settings and settings["columns"]) else []
         keep: str = settings["keep"] if ("keep" in settings and settings["keep"]) else "first"
+        columns: list[str] = settings["columns"] if ("columns" in settings and settings["columns"]) else []
         only_subset: bool = settings["only_subset"] if "only_subset" in settings else False
 
         try:
@@ -33,7 +33,7 @@ class DropDuplicates:
 
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
