@@ -15,6 +15,7 @@ from vtarget.utils.encrypter import encrypter
 
 class Email:
     def exec(self, flow_id: str, node_key: str, pin: dict[str, pd.DataFrame], settings: dict):
+        script = []
         streams: list[dict] = []
         files: list[str] = []
         ports: list[str] = [p for p in dict(settings).keys() if str(p).startswith("port_")]
@@ -31,19 +32,24 @@ class Email:
                 sepIdx = len(port_origin) - port_origin[::-1].find("_")
                 parent_key: str = port_origin[0 : sepIdx - 1]
                 parent_port: str = port_origin[sepIdx:]
+                
                 if parent_key is not None and parent_port is not None:
                     # ? Obtener el df del padre desde cache
                     parent_settings = cache_handler.settings[flow_id][parent_key]
                     parent = cache_handler.cache[flow_id][parent_key]
+                    
                     if parent_key.lower().startswith("excel"):  # * Nodos de tipo excel
                         # ? Obtener la ruta del archivo excel generado
                         parent_config: dict = json.loads(parent_settings["config"]) if "config" in parent_settings else {}
                         file_path: str = parent_config["file_path"] if "file_path" in parent_config else None
+                        
                         if file_path is None:
                             output_name: str = parent_config["name"] if "name" in parent_config else None
                             output_path: str = parent_config["path"] if "path" in parent_config else None
+                            
                             if deploy_enabled:
                                 output_path = settings["deploy_path"] if "deploy_path" in settings else None
+                                
                             if output_name and output_path:
                                 file_path = output_path + os.path.sep + output_name + ".xlsx"
                                 file_path = normpath(file_path)
@@ -54,6 +60,7 @@ class Email:
                             # ? sumar peso del excel al total
                             size = os.path.getsize(file_path)
                             total_size += size
+                            
                     else:  # * Cualquier otro tipo de nodos
                         # ? Convertir df del puerto de origen en un csv en memoria
                         df_in: pd.DataFrame = parent["pout"][parent_port] if "pout" in parent and parent_port in parent["pout"] else pd.DataFrame()
@@ -71,9 +78,9 @@ class Email:
         # * Check if total size > 20Mb
         if total_size / (1024 * 1024) > 20:
             msg = app_message.dataprep["nodes"]["email"]["size_max"](node_key, str(validation))
-            return bug_handler.default_on_error(flow_id, node_key, msg)
+            return bug_handler.default_node_log(flow_id, node_key, msg)
 
-        script_handler.script.append("\n# EMAIL")
+        script.append("\n# EMAIL")
         SERVER: str = settings["server"] if "server" in settings and settings["server"] else None
         PORT: str = settings["port"] if "port" in settings and settings["port"] else None
         FROM: str = settings["from"] if "from" in settings and settings["from"] else None
@@ -91,9 +98,8 @@ class Email:
         validation = list(set(["server", "port", "from", "password", "to"]) - set([k for k in settings.keys() if settings[k]]))
 
         if len(validation) != 0:
-            # msg = "(email): Debes completar todos los campos en la configuración. Campos faltantes: " + str(validation)
             msg = app_message.dataprep["nodes"]["email"]["config_required"](node_key, str(validation))
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
         decryptKey = flow_id[:16]
         DECRYPTEDPASS = encrypter.decrypt(PASS, decryptKey) if PASS is not None and decryptKey is not None else ""
@@ -105,7 +111,7 @@ class Email:
 
         except Exception as e:
             msg = app_message.dataprep["nodes"]["email"]["failed_send"](node_key)
-            bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
             return {}
 
         cache_handler.update_node(
@@ -113,8 +119,9 @@ class Email:
             node_key,
             {
                 "config": json.dumps(settings, sort_keys=True),
-                "script": script_handler.script,
+                "script": script,
             },
         )
 
+        script_handler.script += script
         return {}
