@@ -13,9 +13,10 @@ from vtarget.utils import normpath
 
 class ExcelOutput:
     def exec(self, flow_id: str, node_key: str, pin: dict[str, pd.DataFrame], settings: dict):
-        script_handler.script.append("\n# EXCEL")
-        output_name: str = settings["name"] if "name" in settings and settings["name"] else "output"
-        output_path: str = settings["path"] if "path" in settings and settings["path"] else ""
+        script = []
+        script.append("\n# EXCEL")
+        output_name: str = settings["name"] if "name" in settings and settings["name"] != "" else "output"
+        output_path: str = settings["path"] if "path" in settings and settings["path"] != "" else ""
         encoding: str = settings["encoding"] or "UTF-8"
 
         # * Deploy mode habilitado
@@ -23,9 +24,13 @@ class ExcelOutput:
         if deploy_enabled:
             if "deploy_path" not in settings:
                 msg = app_message.dataprep["nodes"]["deploy_enabled"](node_key)
-                return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
             output_path = settings["deploy_path"] if "deploy_path" in settings else ""
+            
+        if not output_path:
+            msg = app_message.dataprep["nodes"]["excel"]["output_path"](node_key)
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
         df1 = pin["In"].copy() if "In" in pin else pd.DataFrame()
         df2 = pin["In2"].copy() if "In2" in pin else pd.DataFrame()
@@ -33,41 +38,41 @@ class ExcelOutput:
         df4 = pin["In4"].copy() if "In4" in pin else pd.DataFrame()
         df5 = pin["In5"].copy() if "In5" in pin else pd.DataFrame()
 
-        sheet_name_1: str = settings["sheet1"] if "sheet1" in settings and settings["sheet1"] else "sheet_1"
-        sheet_name_2: str = settings["sheet2"] if "sheet2" in settings and settings["sheet2"] else "sheet_2"
-        sheet_name_3: str = settings["sheet3"] if "sheet3" in settings and settings["sheet3"] else "sheet_3"
-        sheet_name_4: str = settings["sheet4"] if "sheet4" in settings and settings["sheet4"] else "sheet_4"
-        sheet_name_5: str = settings["sheet5"] if "sheet5" in settings and settings["sheet5"] else "sheet_5"
+        sheet_name_1: str = settings["sheet1"] if "sheet1" in settings and settings["sheet1"] != "" else "sheet_1"
+        sheet_name_2: str = settings["sheet2"] if "sheet2" in settings and settings["sheet2"] != "" else "sheet_2"
+        sheet_name_3: str = settings["sheet3"] if "sheet3" in settings and settings["sheet3"] != "" else "sheet_3"
+        sheet_name_4: str = settings["sheet4"] if "sheet4" in settings and settings["sheet4"] != "" else "sheet_4"
+        sheet_name_5: str = settings["sheet5"] if "sheet5" in settings and settings["sheet5"] != "" else "sheet_5"
 
         file_path = output_path + os.path.sep + output_name + ".xlsx"
         file_path = normpath(file_path)
 
         settings["file_path"] = file_path
-
-        # TODO: Agregar script
         try:
             # Create a excel writer object
             with pd.ExcelWriter(file_path) as writer:
+                script.append(f"with pd.ExcelWriter({file_path}) as writer:")
                 # Use to_excel function and specify the sheet_name and index
                 # to store the dataframe in specified sheet
                 if len(df1) > 0:
                     self.pd_to_excel(df1, writer, sheet_name_1, encoding, True)
-                    # df1.to_excel(writer, sheet_name=sheet_name_1, index=False, encoding=encoding)
+                    script.append(f"\tdf_In1.to_excel(writer, sheet_name='{sheet_name_1}', index=False, encoding='{encoding}')")
                 if len(df2) > 0:
                     self.pd_to_excel(df2, writer, sheet_name_2, encoding)
-                    # df2.to_excel(writer, sheet_name=sheet_name_2, index=False, encoding=encoding)
+                    script.append(f"\tdf_In2.to_excel(writer, sheet_name='{sheet_name_2}', index=False, encoding='{encoding}')")
                 if len(df3) > 0:
                     self.pd_to_excel(df3, writer, sheet_name_3, encoding)
-                    # df3.to_excel(writer, sheet_name=sheet_name_3, index=False, encoding=encoding)
+                    script.append(f"\tdf_In3.to_excel(writer, sheet_name='{sheet_name_3}', index=False, encoding='{encoding}')")
                 if len(df4) > 0:
                     self.pd_to_excel(df4, writer, sheet_name_4, encoding)
-                    # df4.to_excel(writer, sheet_name=sheet_name_4, index=False, encoding=encoding)
+                    script.append(f"\tdf_In4.to_excel(writer, sheet_name='{sheet_name_4}', index=False, encoding='{encoding}')")
                 if len(df5) > 0:
                     self.pd_to_excel(df5, writer, sheet_name_5, encoding)
-                    # df5.to_excel(writer, sheet_name=sheet_name_5, index=False, encoding=encoding)
+                    script.append(f"\tdf_In5.to_excel(writer, sheet_name='{sheet_name_5}', index=False, encoding='{encoding}')")
+                    
         except Exception as e:
             msg = app_message.dataprep["nodes"]["excel"]["failed_generate"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         out = []
         sheet_names = [sheet_name_1, sheet_name_2, sheet_name_3, sheet_name_4, sheet_name_5]
@@ -90,9 +95,11 @@ class ExcelOutput:
             {
                 "pout": {"Out": df},
                 "config": json.dumps(settings, sort_keys=True),
-                "script": script_handler.script,
+                "script": script,
             },
         )
+        
+        script_handler.script += script
 
         return {"Out": df}
 
