@@ -17,17 +17,19 @@ class Filter:
     def exec(self, flow_id: str, node_key: str, pin: dict[str, pd.DataFrame], settings: dict):
         if "rule_type" not in settings:
             msg = app_message.dataprep["nodes"]["filter"]["rules"](node_key)
-            bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
             return {"T": pd.DataFrame(), "F": pd.DataFrame()}
 
         df: pd.DataFrame = pin["In"].copy()
         df_T, df_F = pd.DataFrame(), pd.DataFrame()
+        
+        # NOTE: en versiones nuevas ya no se usa
         if settings["rule_type"] == "preconfigured":
             try:
                 df_T, df_F = self.filter_preconfigured(flow_id, node_key, df, settings)
             except Exception as e:
                 msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-                bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+                bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
                 return {"T": pd.DataFrame(), "F": pd.DataFrame()}
 
         elif settings["rule_type"] == "code":
@@ -46,6 +48,7 @@ class Filter:
 
                     current_path = os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(__file__))))
                     python_path = os.path.join(current_path, "python", "python")
+                    
                     if os.path.exists(python_path):
                         subprocess.run(
                             [
@@ -59,16 +62,18 @@ class Filter:
                         )
                     else:
                         import pip
-
                         pip.main(["install", m["name"].split(".")[0]])
+                        
                     if m["alias"]:
                         globals()[m["alias"]] = importlib.import_module(m["name"])
                     else:
                         globals().update(importlib.import_module(m["name"]).__dict__)
+                        
             df_T, df_F = self.filter_code(flow_id, node_key, df, settings["sentence"])
         else:
             msg = app_message.dataprep["nodes"]["filter"]["unknow_rule"](node_key, str(settings["rule_type"]))
-            bug_handler.default_on_error(flow_id, node_key, msg, console_level="warn", bug_level="warning")
+            bug_handler.default_node_log(flow_id, node_key, msg, console_level="warn", bug_level="warning")
+            
         cache_handler.update_node(
             flow_id,
             node_key,
@@ -86,12 +91,13 @@ class Filter:
     def filter_code(self, flow_id, node_key, df, sentence):
         self.script.append("\n# FILTER (CUSTOMIZED)")
         str_rule = "df[{}]".format(sentence)
+        
         try:
             df_T = eval(str_rule)
             self.script.append("df_T = {}".format(str_rule))
         except Exception as e:
             msg = app_message.dataprep["nodes"]["filter"]["failed_condition"](node_key)
-            bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
             return pd.DataFrame(), pd.DataFrame()
         else:
             # Obtengo el complemento (la parte negada de la condición)
@@ -99,7 +105,7 @@ class Filter:
             self.script.append("df_F = df[~df.index.isin(df_T.index)]")
             return df_T, df_F
 
-    # Nodo: filter - Procesa el filtro preconfigurado
+    # Nodo: filter - Procesa el filtro preconfigurado (Deprecated en neuvas versiones)
     def filter_preconfigured(self, flow_id, node_key, df: pd.DataFrame, rule):
         df_T, df_F = pd.DataFrame(), pd.DataFrame()
         self.script.append("\n# FILTER (PRECONFIGURED)")
@@ -110,7 +116,7 @@ class Filter:
         if field not in df.columns:
             # msg = "(filter_code) No existe la columna {} en el dataframe de entrada".format(field)
             msg = app_message.dataprep["nodes"]["filter"]["unknow_column"](node_key, field)
-            bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
             return pd.DataFrame(), pd.DataFrame()
 
         if pd.api.types.is_datetime64_any_dtype(df[field]):
@@ -177,7 +183,7 @@ class Filter:
             self.script.append(f"df_T = {str_rule}")
         else:
             msg = app_message.dataprep["filter"]["unknow_operator"](node_key, rule["operator"])
-            bug_handler.default_on_error(flow_id, node_key, msg, console_level="error", bug_level="error")
+            bug_handler.default_node_log(flow_id, node_key, msg, console_level="error", bug_level="error")
         # Obtengo el complemento (la parte negada de la condición)
         df_F = df[~df.index.isin(df_T.index)]
         self.script.append(f"df_F = df[~df.index.isin(df_T.index)]")
