@@ -52,13 +52,16 @@ class Formula:
                     globals()[m["alias"]] = importlib.import_module(m["name"])
                 else:
                     globals().update(importlib.import_module(m["name"]).__dict__)
+                    
+        formulas: list = settings["items"] if "items" in settings else []
 
-        for i, item in enumerate(settings["items"]):
+        for i, item in enumerate(formulas):
             col_name: str = ""
             if not item["field"]:  # crea una columna nueva
                 col_name = item["new_column_name"] if "new_column_name" in item and item["new_column_name"] else f"x_{i}"
-            else:  # Edita una existente
+            else:  # actualiza la misma columna seleccionada
                 col_name = item["field"]
+                
             if "sentence" not in item:
                 continue
 
@@ -68,7 +71,7 @@ class Formula:
                 script.append("df.loc[:, '{}'] = {}".format(col_name, item["sentence"]))
             except Exception as e:
                 msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-                return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+                return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
