@@ -39,8 +39,8 @@ class Groupby:
             return sum(x == "")
 
         # https://www.analyticsvidhya.com/blog/2020/03/groupby-pandas-aggregating-data-python/
-        group_by_cols = settings["group_by"] if "group_by" in settings and settings["group_by"] else []
-        aggs = settings["agg"] if "agg" in settings and settings["agg"] else []
+        group_by_cols: list = settings["group_by"] if "group_by" in settings and settings["group_by"] else []
+        aggs: list = settings["agg"] if "agg" in settings and settings["agg"] else []
         agg_cols = {}
         pctl_replaces2 = []
         rename_cols = {}
@@ -58,17 +58,16 @@ class Groupby:
                         action = fn_name
                         pctl_replaces2.append((fn_name, pctl_value))
 
-                # Luego agrupo las funciones de agregación
+                # Agrupar las funciones de agregación
                 if column not in agg_cols:
                     agg_cols[column] = [action]
                 else:
-                    # Valido que no se agreguen agregaciones repetidas
+                    # Validar que no se agreguen agregaciones repetidas
                     if action not in agg_cols[column]:
                         agg_cols[column].append(action)
 
-                # Creo el nombre compuesto entre la columna y la fn de agg para renombrar la columna
+                # Crear el nombre compuesto entre la columna y la fn de agg para renombrar la columna
                 current_name = column + "_" + action
-                # rename_cols[current_name] = column # por defecto renombra sin "action" prop como sufijo
                 
                 # Si viene una columna de agregación con un renombre desde la vista
                 if "rename" in agg_method and agg_method["rename"]:
@@ -77,8 +76,8 @@ class Groupby:
                     if "suffix" in agg_method and bool(agg_method["suffix"]) == False:
                         rename_cols[current_name] = column
             else:
-                msg = "some of the properties of aggregate method have not been provided"
-                return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                msg = app_message.dataprep["nodes"]["group_by"]["missing_props"](node_key)
+                return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
         agg_str = str(agg_cols)
         for pr in pctl_replaces2:
@@ -90,7 +89,7 @@ class Groupby:
         if "mode" in agg_str:
             agg_str = agg_str.replace("'mode'", "mode")
 
-        grouped = pd.DataFrame()
+        grouped: pd.DataFrame = pd.DataFrame()
         try:
             if group_by_cols:
                 grouped = eval("df.groupby(group_by_cols).agg({}).reset_index()".format(agg_str))
@@ -104,13 +103,13 @@ class Groupby:
                 script.append("grouped = df.groupby(lambda _ : 1).agg({}).reset_index()".format(agg_str))
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         try:
             grouped.rename(columns=rename_cols, inplace=True)
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
