@@ -38,7 +38,7 @@ class InterRow:
                 msg = app_message.dataprep["nodes"]["missing_column"](node_key)
             if fillna and (not fillna_value and not fillna_value_timedelta):
                 msg = app_message.dataprep["nodes"]["inter_row"]["fillna"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
         try:
             query = ""
@@ -69,7 +69,7 @@ class InterRow:
 
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
