@@ -18,7 +18,7 @@ class Merge:
 
         if "iL" not in pin or "iR" not in pin:
             msg = app_message.dataprep["nodes"]["merge"]["input_port"](node_key)
-            bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
             return pout_struct
 
         self.script.append("\n# MERGE")
@@ -28,20 +28,20 @@ class Merge:
         right_columns: list[str] = settings["right_columns"] if "right_columns" in settings else []
 
         # * Dataframes de entrada
-        df_iL = pin["iL"].copy()
-        df_iR = pin["iR"].copy()
+        df_iL: pd.DataFrame = pin["iL"].copy() if "iL" in pin else pd.DataFrame()
+        df_iR: pd.DataFrame = pin["iR"].copy() if "iR" in pin else pd.DataFrame()
 
         # * Validar que array de columnas de salida exista en su respectivo DF
         for col in left_columns:
             if col not in df_iL.columns.tolist():
                 msg = app_message.dataprep["nodes"]["merge"]["input_port_il"](node_key, col)
-                bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
                 return pout_struct
 
         for col in right_columns:
             if col not in df_iR.columns.tolist():
                 msg = app_message.dataprep["nodes"]["merge"]["input_port_iR"](node_key, col)
-                bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
                 return pout_struct
 
         try:
@@ -52,7 +52,7 @@ class Merge:
             on_r: list[str] = [x["right"] for x in settings["items"] if "right" in x and x["right"]]
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
             return pout_struct
 
         if "L" in settings["outputs"]:
@@ -97,7 +97,7 @@ class Merge:
                 self.script.append("df_o = pd.merge(df_iL, df_iR, left_on={}, right_on={}, how='{}', indicator=True)".format(on_l, on_r, how))
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
             return pd.DataFrame()
         return df_o
 
