@@ -12,7 +12,8 @@ from vtarget.utils import normpath
 
 class Output:
     def exec(self, flow_id: str, node_key: str, pin: dict[str, pd.DataFrame], settings: dict):
-        script_handler.script.append("\n# OUPUT")
+        script = []
+        script.append("\n# OUPUT")
         output_format: str = settings["format"] or "csv"
         output_name: str = settings["name"] if "name" in settings else "output"
         output_path: str = settings["path"] if "path" in settings else ""
@@ -23,12 +24,20 @@ class Output:
         if deploy_enabled:
             if "deploy_path" not in settings:
                 msg = app_message.dataprep["nodes"]["deploy_enabled"](node_key)
-                return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+                return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
             output_path = settings["deploy_path"] if "deploy_path" in settings else ""
 
-        script = ""
-        df: pd.DataFrame = pin["In"].copy()
+        df: pd.DataFrame = pin["In"].copy() if "In" in pin else pd.DataFrame()
+        
+        if not output_name:
+            msg = app_message.dataprep["nodes"]["required_prop"](node_key, "Output Name")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
+        
+        if not output_path:
+            msg = app_message.dataprep["nodes"]["required_prop"](node_key, "Folder path")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
+        
         try:
             if output_format == "excel":
                 file_path = output_path + os.path.sep + output_name + ".xlsx"
@@ -38,7 +47,7 @@ class Output:
                     index=False,
                     encoding=encoding,
                 )
-                script = f"df.to_excel('{file_path}', index= False, encoding={encoding})"
+                script.append(f"df.to_excel('{file_path}', index=False, encoding='{encoding}')")
             else:
                 file_path = output_path + os.path.sep + output_name + ".csv"
                 file_path = normpath(file_path)
@@ -47,22 +56,21 @@ class Output:
                     encoding=encoding,
                     index=False,
                 )
-                script = f"df.to_csv('{file_path}', index= False, encoding={encoding})"
-
-            cache_handler.update_node(
-                flow_id,
-                node_key,
-                {
-                    "config": json.dumps(settings, sort_keys=True),
-                    "script": script,
-                },
-            )
-
-            script_handler.script.append(script)
+                script.append(f"df.to_csv('{file_path}', index=False, encoding='{encoding}')")
 
         except Exception as e:
             print("Error (output): ", e)
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+        
+        cache_handler.update_node(
+            flow_id,
+            node_key,
+            {
+                "config": json.dumps(settings, sort_keys=True),
+                "script": script,
+            },
+        )
 
+        script_handler.script += script
         return df
