@@ -16,11 +16,11 @@ class Shape:
         script.append("\n# SHAPE")
 
         try:
-            script.append("df_shape = pd.DataFrame([df.shape], columns=['num_rows', 'num_columns'])")
             df = pd.DataFrame([df.shape], columns=["num_rows", "num_columns"])
+            script.append("df_shape = pd.DataFrame([df.shape], columns=['num_rows', 'num_columns'])")
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
