@@ -20,14 +20,14 @@ class Unique:
 
         if not field:
             msg = app_message.dataprep["nodes"]["missing_column"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
         try:
             df = df.groupby(field).size().reset_index().drop(columns=[0])
             script.append("df = df.groupby({}).size().reset_index().drop(columns=[0])".format(field))
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
