@@ -7,7 +7,7 @@ from vtarget.handlers.cache_handler import cache_handler
 
 
 class VOutput:
-    def exec(self, flow_id, node_key, pin, settings):
+    def exec(self, flow_id: str, node_key: str, pin: dict[str, pd.DataFrame], settings: dict):
         df: pd.DataFrame = pin["In"].copy()
 
         cache_handler.update_node(
@@ -21,7 +21,4 @@ class VOutput:
             },
         )
 
-        bug_handler.console(f'[Nodo]: "{node_key}" almacenado en cache', "info", flow_id)
-        # script_handler.script += script
-
         return pd.DataFrame()
