@@ -14,13 +14,13 @@ class ValueCounts:
         df: pd.DataFrame = pin["In"].copy()
         script.append("\n# VALUE_COUNTS")
 
-        if "field" not in settings:
-            msg = app_message.dataprep["nodes"]["missing_column"](node_key)
-            return bug_handler.default_on_error(flow_id, node_key, msg, console_level="error")
-
-        field: str = settings["field"]
+        field: str = settings["field"] if "field" in settings else None
         ascending: bool = settings["ascending"] if "ascending" in settings else True
         drop_na: bool = settings["drop_na"] if "drop_na" in settings else False
+        
+        if not field:
+            msg = app_message.dataprep["nodes"]["missing_column"](node_key)
+            return bug_handler.default_node_log(flow_id, node_key, msg, console_level="error")
 
         try:
             df_pct = df.value_counts(subset=field, normalize=True, ascending=ascending, dropna=drop_na)
@@ -44,7 +44,7 @@ class ValueCounts:
 
         except Exception as e:
             msg = app_message.dataprep["nodes"]["exception"](node_key, str(e))
-            return bug_handler.default_on_error(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
+            return bug_handler.default_node_log(flow_id, node_key, msg, f"{e.__class__.__name__}({', '.join(e.args)})")
 
         cache_handler.update_node(
             flow_id,
