@@ -1,10 +1,12 @@
 class Pipeline:
     def __init__(self):
+        from vtarget.dataprep.nodes.api_rest import ApiRest
         from vtarget.dataprep.nodes.code import Code
         from vtarget.dataprep.nodes.column import Column
         from vtarget.dataprep.nodes.concat import Concat
         from vtarget.dataprep.nodes.cross_join import CrossJoin
         from vtarget.dataprep.nodes.cumsum import Cumsum
+        from vtarget.dataprep.nodes.cut import Cut
         from vtarget.dataprep.nodes.data_cleansing import DataCleansing
         from vtarget.dataprep.nodes.database import Database
         from vtarget.dataprep.nodes.database_write import DatabaseWrite
@@ -29,16 +31,18 @@ class Pipeline:
         from vtarget.dataprep.nodes.output import Output
         from vtarget.dataprep.nodes.pivot import Pivot
         from vtarget.dataprep.nodes.rolling import Rolling
+        from vtarget.dataprep.nodes.sample import Sample
         from vtarget.dataprep.nodes.shape import Shape
         from vtarget.dataprep.nodes.sort import Sort
+        from vtarget.dataprep.nodes.split import Split
         from vtarget.dataprep.nodes.switch import Switch
         from vtarget.dataprep.nodes.unique import Unique
         from vtarget.dataprep.nodes.v_output import VOutput
         from vtarget.dataprep.nodes.value_counts import ValueCounts
-        from vtarget.dataprep.nodes.sample import Sample
 
         self.decimal_round = False
         self.nodes_instances = {
+            "API_Rest": ApiRest(),
             "Input_Data": InputData(),
             "Database": Database(),
             "Database_Write": DatabaseWrite(),
@@ -77,6 +81,8 @@ class Pipeline:
             "Rolling": Rolling(),
             "Datetime_Fill": DatetimeFill(),
             "Sample": Sample(),
+            "Split": Split(),
+            "Cut": Cut(),
         }
 
     def exec(self, flow_id: str, node: dict, input_port: dict):
@@ -94,7 +100,7 @@ class Pipeline:
 
         settings = node["meta"]["config"] if "config" in node["meta"] else dict()
         max_rows: int = settings["max_rows"] if "max_rows" in settings else 0
-
+        
         dict_pout: Dict[pd.DataFrame] = self.nodes_instances[node["type"]].exec(
             flow_id,
             node["key"],
@@ -106,7 +112,7 @@ class Pipeline:
             for pout in dict_pout:
                 if isinstance(dict_pout[pout], pd.DataFrame) and dict_pout[pout].shape[0] > max_rows:
                     msg = app_message.dataprep["builder"]["max_rows"](node["key"], max_rows)
-                    bug_handler.default_on_error(flow_id, node["key"], msg, console_level="warn", bug_level="warning")
+                    bug_handler.default_node_log(flow_id, node["key"], msg, console_level="warn", bug_level="warning")
                     dict_pout[pout] = dict_pout[pout].head(max_rows)
 
         if "STDOUT" in dict_pout:
