@@ -42,7 +42,7 @@ class Bug_Handler:
         print(colored(f"[{level}] {msg}", color))
         log_handler.append({"flow_id": flow_id, "level": level, "msg": msg, "color": color}, emit)
 
-    def default_on_error(
+    def default_node_log(
         self,
         flow_id: str,
         node_key: str,
