@@ -7,9 +7,9 @@ import pandas as pd
 from pandas.api.types import is_numeric_dtype
 from scipy import stats
 
-from vtarget.language.app_message import app_message
-from vtarget.handlers.cache_handler import cache_handler
 from vtarget.handlers.bug_handler import bug_handler
+from vtarget.handlers.cache_handler import cache_handler
+from vtarget.language.app_message import app_message
 
 
 class Utilities:
@@ -55,9 +55,9 @@ class Utilities:
                     if is_subset:
                         full_df = full_df.sort_values(by=list(columns), ascending=list(order))
                     else:
-                        #TODO: @Pancho agregar al diccionario de idioma
-                        bug_handler.default_on_error(flow_id, node_key, "Some sort columns no longer exist in the results table", console_level="WARN", bug_level="warning")
-                    
+                        msg = app_message.utils["utilities"]["sort_column_not_in_df"]
+                        bug_handler.default_node_log(flow_id, node_key, msg, console_level="WARN", bug_level="warning")
+
         return full_df
 
     def get_head_of_df_as_list(
@@ -68,11 +68,18 @@ class Utilities:
         node_key: str = None,
         port_name: str = None,
     ):
+        # * Check if exists duplicated columns
+        if any(port_df.columns.duplicated()):
+            duplicated : pd.DataFrame = port_df.loc[:, port_df.columns.duplicated()]
+            msg = app_message.utils["utilities"]["duplicated_columns"](" ,".join(duplicated.columns.to_list()))
+            bug_handler.default_node_log(flow_id, node_key, msg, console_level="WARN", bug_level="warning")
+            # * Remove dupicated columns from Dataframe
+            port_df = port_df.loc[:, ~port_df.columns.duplicated()]
+
         df: pd.DataFrame = port_df.head(50).copy()
         page_num = config["page"] if "page" in config else 1
         page_size = len(port_df) if "rows" in config and config["rows"] > len(port_df) else config["rows"]
-        offset = page_size * (page_num - 1)
-
+        
         # sort
         if df is not None and len(df) and "sort_by" in config and len(config["sort_by"]) > 0:
             port_df = self.sort_df(port_df, config["sort_by"], flow_id, node_key)
@@ -85,12 +92,14 @@ class Utilities:
                     cache_handler.update_node(flow_id, node_key, {"pout": cached_node["pout"]})
 
         if config["source"] == "head":
-            df = port_df[offset : offset + page_size].copy()
+            start = page_size * (page_num - 1)
+            df = port_df[start : start + page_size].copy()
         elif config["source"] == "tail":
-            if offset == page_size:
-                df = port_df[-offset:].copy()
+            start = page_size * (page_num)
+            if start == page_size:
+                df = port_df[-start:].copy()
             else:
-                df = port_df[-offset : -offset + page_size].copy()
+                df = port_df[-start : -start + page_size].copy()
         elif config["source"] == "sample":
             df = port_df.sample(page_size).copy()
             if len(df) and "sort_by" in config and len(config["sort_by"]) > 0:
@@ -119,19 +128,30 @@ class Utilities:
                 "float16",
                 "float32",
                 "float64",
+                # "Int8", # tipo de dato Bigquery
+                # "Int16", # tipo de dato Bigquery
+                # "Int32", # tipo de dato Bigquery
+                # "Int64", # tipo de dato Bigquery
+                # "Float16", # tipo de dato Bigquery
+                # "Float32", # tipo de dato Bigquery
+                # "Float64", # tipo de dato Bigquery
             ]
         ).columns.values.tolist()
 
         if len(special_cols):
-            # print(special_cols)
             df[special_cols] = df[special_cols].astype(str)
 
-        # TODO: Ver qué problema entrega esta línea con los vacíos int y string
-        df = df.fillna("NaN")  # df = df.fillna(np.nan)
+        try:
+            df = df.fillna("NaN")
+        except Exception as e:
+            df.replace([None, ''], np.nan, inplace=True)
+
+        try:
+            df.replace(["nan", "None", None, ''], "NaN", inplace=True)
+        except Exception as e:
+            df.replace(["nan", "None", None, ''], np.nan, inplace=True)
+
 
-        # df = df.replace([np.inf, -np.inf], 0, inplace=True)
-        # print(bool_cols)
-        # df_head = [df.columns.values.tolist()] + df.values.tolist()
         df_head = df.to_dict("records")
         return df_head
 
